import request from '@/utils/request'
import type { ResponseBody } from '@/api/typing'

const GAME_BASE_URL = '/game'
const GAME_BASE_URL_2 = '/record'

class GameAPI {
  /**
   * 通过ID查询游戏信息
   *
   * @returns 游戏名称、编码等
   */
  static findById(id: string) {
    return request<any, ResponseBody<GameVO>>({
      url: `${GAME_BASE_URL}/findById`,
      method: 'get',
      params: { id },
    })
  }

  /**
   * 添加游戏结果数据
   *
   * @param data 游戏结果数据
   */
  static add(data: GameResultVO) {
    return request({
      url: `${GAME_BASE_URL_2}/save`,
      method: 'post',
      data,
    })
  }

  /**
   * 修改游戏
   *
   * @param data 游戏表单数据
   */
  // static update(data: GameVO) {
  //   return request({
  //     url: `${GAME_BASE_URL}/update`,
  //     method: 'put',
  //     data: data
  //   })
  // }

  /**
   * 删除游戏
   *
   * @param id 游戏Id
   */
  // static deleteById(id: string) {
  //   return request({
  //     url: `${GAME_BASE_URL}/delete/${id}`,
  //     method: 'delete'
  //   })
  // }
}

export default GameAPI

/** 游戏信息 */
export interface GameVO {
  /** 游戏ID */
  id?: number | string
  /** 游戏名称 */
  name?: string
  /** 游戏编码 */
  code?: string
  /** 游戏简介 */
  intro?: string
}

/** 游戏记录信息 */
export interface GameResultVO {
  /** 游戏记录ID */
  id?: string
  /** 完成(0:未完成 1:已完成) */
  finish?: string
  /** 游戏ID */
  gameId?: string | number
  /** 游戏名称 */
  gameName?: string
  /** 游戏等级 */
  gamelevel?: string | number
  /** 游戏得分 */
  score?: number
  /** 用户ID */
  userId?: string
  /** 游戏结果参数 */
  paramList?: Result[]
  /** 游戏结果参数(关卡) */
  levelList?: ResultLevel[]
}

export interface Result {
  code?: string
  name?: string
  value?: string | number
}

export interface ResultLevel {
  level?: string | number
  levelParamList?: Result[]
}
